from pyspark.sql import SparkSession
from pyspark.sql.dataframe import DataFrame

from .defs import PACKAGES
from .utils import get_catalog_config


class Spark:

    def __init__(self, 
                client_id: str,
                client_secret: str,
                env: str = 'staging',
                master: str = 'local'
            ):
        catalog_config = get_catalog_config(client_id, client_secret, env)
        self._spark = (
            SparkSession.builder
            .master(master)
            .config("spark.jars", PACKAGES)
            .config("spark.sql.extensions", "org.apache.iceberg.spark.extensions.IcebergSparkSessionExtensions")
            .config("spark.sql.defaultCatalog", "staging_nessie")
            .config(map=catalog_config)
            .getOrCreate()
        )

    def get_spark_session(self) -> SparkSession:
        return self._spark

    def sql(self, sqlQuery: str) -> DataFrame:
        return self._spark.sql(sqlQuery)
